summaryrefslogtreecommitdiff
path: root/misc/sword15/files/patch-src::mgr::swmgr.cpp
blob: fe0db28f4cb7a72a7e464c2701776c83d4447c67 (plain) (blame)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
--- src/mgr/swmgr.cpp.org	Wed Dec 12 00:43:04 2001
+++ src/mgr/swmgr.cpp	Wed Dec 12 00:44:39 2001
@@ -268,21 +268,21 @@
 	}
 
 
 	// check for systemwide /etc/sword.conf
 
 #ifndef __VISUALC__
 if (debug)
-	cerr << "\nChecking for /etc/sword.conf...";
+	cerr << "\nChecking for "_INSTDIR_"/etc/sword.conf...";
 #endif
 
-	if (!::access("/etc/sword.conf", 04)) {
+	if (!::access(_INSTDIR_"/etc/sword.conf", 04)) {
 
 #ifndef __VISUALC__
 if (debug)
 	cerr << "found\n";
 #endif
 
-		SWConfig etcconf("/etc/sword.conf");
+		SWConfig etcconf(_INSTDIR_"/etc/sword.conf");
 		if ((entry = etcconf.Sections["Install"].find("DataPath")) != etcconf.Sections["Install"].end()) {
 			path = (*entry).second;
 			if (((*entry).second.c_str()[strlen((*entry).second.c_str())-1] != '\\') && ((*entry).second.c_str()[strlen((*entry).second.c_str())-1] != '/'))
@@ -290,7 +290,7 @@
 
 #ifndef __VISUALC__
 if (debug)
-	cerr << "DataPath in /etc/sword.conf is set to: " << path;
+	cerr << "DataPath in "_INSTDIR_"/etc/sword.conf is set to: " << path;
 #endif
 
 #ifndef __VISUALC__
@@ -268,21 +268,21 @@
 
 
-	// check for systemwide /etc/sword.conf
+	// check for systemwide _INSTDIR_/etc/sword.conf
 
 #ifndef __VISUALC__